<?php

/**
 * @file
 *
 * Theme functions
 */

/**
 * Implements HOOK_theme().
 */
function om_theme() {
  //dsm($type);
  return array(
    'identity' => array(
      'variables' => array('logo' => NULL, 'site_name' => NULL, 'site_slogan' => NULL, 'front_page' => NULL),
    ),
    'region_wrapper' => array( /* @Legacy - soon will be deleted */
      'variables' => array('region' => NULL, 'region_classes' => NULL, 'region_inner' => 0),
    ),
    'content_elements' => array(
      'variables' => array('tabs' => NULL, 'prefix' => NULL, 'title' => NULL, 'suffix' => NULL, 'action' => NULL),
    ),    
    'menu' => array(
      'variables' => array('menu_name' => NULL, 'menu' => NULL, 'menu_tree' => NULL),
    ),              
  );
}



/**
 * Logo, Site Name, Site Slogan
 */
function om_identity($vars) {
  if (!empty($vars['logo']) || !empty($vars['site_name']) || !empty($vars['site_slogan'])) { 
    $out = '<div id="logo-title">';
    if (!empty($vars['logo'])) $out .= '<a href="' . $vars['front_page'] . '" title="' . t('Home') . '" rel="home" id="logo"><img src="' . $vars['logo'] . '" alt="' . t('Home') . '" /></a>';
    if (!empty($vars['site_name']) || !empty($vars['site_slogan'])) { 
      $out .= '<div id="name-and-slogan">';
      if (!empty($vars['site_name'])) $out .= '<h1 id="site-name"><a href="' . $vars['front_page'] . '" title="' . t('Home') . '" rel="home">' . $vars['site_name'] . '</a></h1>';
      if (!empty($vars['site_slogan'])) $out .= '<div id="site-slogan">' . $vars['site_slogan'] . '</div>';
      $out .= '</div> <!-- /#name-and-slogan -->';
    }    
    $out .= '</div> <!-- /#logo-title -->';
    return $out;
  }
}


/**
 * Main, Secondary Menus
 *
 */
function om_menu($vars) {
  if (isset($vars['menu_tree'])) return '<div id="menubar-' . $vars['menu_name'] . '" class="menubar">' . render($vars['menu_tree']) . '</div>';
}

/**
 * Added menu-id to li classes
 *
 */
function om_menu_link(array $variables) {
  $element = $variables['element'];
  $sub_menu = '';
  
  $mlid = $element['#original_link']['mlid'];
  $element['#attributes']['class'][] = 'menu-' . $mlid;
  if ($element['#below']) $sub_menu = drupal_render($element['#below']);
  
  // OM Tools integration
  if (module_exists('om_tools')) {
    $om_tools_values = variable_get('om_tools', '');
    if (isset($om_tools_values['menu']) && ($om_tools_values['menu']['menu_classes_switch'] == 1)) {
      $class = isset($om_tools_values['menu']['menu_classes_' . $mlid]) ? $om_tools_values['menu']['menu_classes_' . $mlid]: ''; 
      $element['#localized_options']['attributes']['class'][] = $class;
    }
  }
    
  $output = l($element['#title'], trim($element['#href']), $element['#localized_options']);
  return '<li' . drupal_attributes($element['#attributes']) . '>' . $output . $sub_menu . "</li>\n";
}

/**
 * Process all region formats
 *
 * @Legacy - soon will be deleted 
 * 
 */
function om_region_wrapper($vars) {
  //dsm($vars);
  if ($vars['region']) { 
    $id           = preg_replace('/_/', '-', $vars['region']['#region']);
    $classes      = $vars['region_classes'];
    $region_inner = $vars['region_inner'];
    
    $div_prefix = '<div id="' . $id . '" class="region region-' . $id . ' ' . $classes . '">'; 
    $div_suffix = '<div class="om-clearfix"></div></div><!-- /#' . $id. ' -->'; 

    if ($region_inner == 1) { 
      $div_prefix .= '<div id="' . $id . '-inner" class="region-inner">'; 
      $div_suffix = '<div class="om-clearfix"></div></div><!-- /#' . $id . '-inner --></div><!-- /#' . $id . ' -->'; 
    }
    return $div_prefix . render($vars['region']) . $div_suffix;
  }
}

/**
 * Process all region variables
 * This is an added function to satisfy the second array argument passed through theme()
 *
 * @Legacy - soon will be deleted 
 * 
 */
function _region_vars($region = NULL, $region_classes = NULL, $region_inner = 0) {
  return array('region' => $region, 'region_classes' => $region_classes, 'region_inner' => $region_inner);
}

/**
 * Preprocess variables for region.tpl.php
 *
 * Prepare the values passed to the theme_region function to be passed into a
 * pluggable template engine. Uses the region name to generate a template file
 * suggestions. If none are found, the default region.tpl.php is used.
 *
 * @see drupal_region_class()
 * @see region.tpl.php
 */
/* 
function om_preprocess_region(&$vars) {
  // get region inner variable
  //dsm($vars);
}
*/

/**
 * Returns HTML for a breadcrumb trail.
 *
 * @param $vars
 *   An associative array containing:
 *   - breadcrumb: An array containing the breadcrumb links.
 */
function om_breadcrumb($vars) {
  $breadcrumb = $vars['breadcrumb'];

  if (!empty($breadcrumb)) {
    // Provide a navigational heading to give context for breadcrumb links to
    // screen-reader users. Make the heading invisible with .element-invisible.
    $output = '<h2 class="element-invisible">' . t('You are here') . '</h2>';

    $output .= '<div class="breadcrumb">' . implode(' » ', $breadcrumb) . '</div>';
    return $output;
  }
}

/**
 * Process all content elements
 */
function om_content_elements($vars) {
  $out = '';
  if (!empty($vars['tabs']))   $out .= '<div class="tabs">' . render($vars['tabs']) . '</div>'; 
  if (!empty($vars['prefix'])) $out .= render($vars['prefix']); 
  if (!empty($vars['title']))  $out .= '<h1 class="title" id="page-title">' . preg_replace('/\[break\]/', '<br />', $vars['title']) . '</h1>'; 
  if (!empty($vars['suffix'])) $out .= render($vars['suffix']); 
  if (!empty($vars['action'])) $out .= '<ul class="action-links">' . render($vars['action']) . '</ul>'; 
  return $out;
}

/**
 * Converts a string to a suitable html ID attribute.
 *
 * http://www.w3.org/TR/html4/struct/global.html#h-7.5.2 specifies what makes a
 * valid ID attribute in HTML. This function:
 *
 * - Ensure an ID starts with an alpha character by optionally adding an 'id'.
 * - Replaces any character except alphanumeric characters with dashes.
 * - Converts entire string to lowercase.
 *
 * @param $string
 *   The string
 * @return
 *   The converted string
 */
function om_id_safe($string) {
  // Replace with dashes anything that isn't A-Z, numbers, dashes, or underscores.
  return strtolower(preg_replace('/[^a-zA-Z0-9-]+/', '-', $string));
}

/**
 * Process variables for html.tpl.php
 *
 * Perform final addition and modification of variables before passing into
 * the template. To customize these variables, call drupal_render() on elements
 * in $vars['page'] during THEME_preprocess_page().
 *
 * @see template_preprocess_html()
 * @see html.tpl.php
 */
function om_preprocess_html(&$vars) {

  $vars['head_title'] = preg_replace('/\[break\]/', '', $vars['head_title']);

	// This  functionality will soon be transferred to OM Tools
  if (!module_exists('om_tools')) {

    $classes = $vars['classes_array'];
 
    if (!$vars['is_front']) {
    
      // Add unique class for each page.
      $path = drupal_get_path_alias($_GET['q']);
      
      // path title
      $classes[] = om_id_safe('page-' . $path);
      
      // default section
      list($section) = explode('/', $path, 2);

      $arg = arg(); // get all arguments
      
      // the page must be a node
      if ($arg[0] == 'node') {
      
        // a better way of getting node types for D7
        $node = menu_get_object();       
         
        $node_type = (is_object($node)) ? $node->type: '';
              
        if (($arg[1] == 'add') && isset($arg[2])) { // add node
          $section      = 'node-add';                    
          $page_type    = $arg[2];                     
          $page_type_op = $page_type . '-add';         
        }
        elseif (($arg[1] == 'add') && !isset($arg[2])) { // add any node
          $section      = 'node-add';               
          $page_type    = 'any';                    
          $page_type_op = $page_type . '-add';           
        }          
        elseif (is_numeric($arg[1]) && !isset($arg[2]) && empty($node_type)) { // not found
          $section      = 'page-not-found';              
          $page_type    = 'any';                    
          $page_type_op = $page_type . '-view';         
        }
        elseif (is_numeric($arg[1]) && !isset($arg[2])) { // view node
          // default $section                        
          $page_type    = $node_type;                  
          $page_type_op = $page_type . '-view';          
        }					
        elseif (is_numeric($arg[1]) && isset($arg[2])) { // has arg 2, like delete, edit, etc.
          $section      = 'node-' . $arg[2];               
          $page_type    = !empty($node_type) ? $node_type: 'any';                   
          $page_type_op = $page_type . '-' . $arg[2];          
        }    
        $classes[] = om_id_safe('content-type-' . $page_type);
        $classes[] = om_id_safe('content-type-' . $page_type_op);
      }       
      $classes[] = om_id_safe('section-' . $section);
    }
    $vars['classes_array'] = $classes;
    $vars['classes'] = implode(' ', $classes); // Concatenate with spaces.	
  }
}

/**
 * Process variables for html.tpl.php
 *
 * Perform final addition and modification of variables before passing into
 * the template. To customize these variables, call drupal_render() on elements
 * in $variables['page'] during THEME_preprocess_page().
 *
 * @see template_preprocess_html()
 * @see html.tpl.php
 */
function om_process_html(&$vars) {
  // for adaptive design based on browser width
  $vars['head'] .= '<meta name="viewport" content="initial-scale=1.0, width=device-width" />';
  // Render page_top and page_bottom into top level variables.
  date_default_timezone_set('UTC');
  $vars['page_bottom'] .= '<div id="legal"><a href="http://www.drupal.org/project/om">OM Base Theme</a> ' . date('Y') . ' | V7.x-2.x | <a href="http://www.danielhonrade.com">Daniel Honrade</a></div>';
}


/**
 * Process regions.php provided on theme
 *
 */
function om_regions_process_info($region = array(), $properties = array()) {

  if ($region) { 
    $id      = $properties['id'];
    $classes = $properties['class'];
    $inner   = $properties['inner'];
    $top     = $properties['top'];
    $bottom  = $properties['bottom'];

    $div_top     = ($top) ? '<div class="region-top"><div class="region-top-left"></div><div class="region-top-right"></div></div>': '';
    $div_bottom  = ($bottom) ? '<div class="region-bottom"><div class="region-bottom-left"></div><div class="region-bottom-right"></div></div>': '';
        
    $div_prefix = '<div id="' . $id . '" class="region region-' . $id . ' ' . $classes . '">' . $div_top; 
    $div_suffix = '<div class="om-clearfix"></div>' . $div_bottom . '</div><!-- /#' . $id. ' -->'; 

    if ($inner) { 
      $div_prefix .= '<div id="' . $id . '-inner" class="region-inner">'; 
      $div_suffix = '<div class="om-clearfix"></div></div>' . $div_bottom . '</div><!-- /#' . $id . '-inner --><!-- /#' . $id . ' -->'; 
    }

    return $div_prefix . render($region) . $div_suffix;
  }
}


/**
 * Get region files
 *
 */  
function om_regions_file_get($file_name = NULL, $type = 'css') {
  global $theme;
  global $theme_path;  
  if (file_exists($theme_path . '/' . $type . '/' . $file_name . '.' . $type)) {
    $function = 'drupal_add_' . $type;
    $function($theme_path . '/' . $type . '/' . $file_name . '.' . $type);
  }  
}

    
/**
 * Override or insert variables into the page template.
 *
 */
function om_preprocess_page(&$vars) {
  global $theme; 
  global $theme_path;
  // Better processing of regions
  if (file_exists($theme_path . '/regions.php')) {
    include_once $theme_path . '/regions.php';

    $regions_system = $vars['page'];    
    $regions = om_regions_get_info();
    foreach ($regions as $region => $properties) {
      // this will just load non-empty regions
      if (isset($regions_system[$region]) && !empty($regions_system[$region])) {
        om_regions_file_get($region, 'css');
        om_regions_file_get($region, 'js');     
        $vars[$region . '_region'] = om_regions_process_info($vars['page'][$region], $properties);
      }
      else {
        $vars[$region . '_region'] = '';
      }
    }
  }

  // OM Tools integration
  $om_tools_values = variable_get('om_tools', '');
  $vars['title'] = drupal_get_title();
  if (module_exists('om_tools')) {
    $node = menu_get_object();        
    if ($node) {
      $node_type = (is_object($node)) ? $node->type: '';
      if (isset($om_tools_values['node']) && ($om_tools_values['node']['node_type_titles_switch'] == 1) && !empty($node_type)) {
        if ($om_tools_values['node']['node_' . $node_type . '_titles'] == 1) $vars['title'] = drupal_set_title('');
      }
    }
  }
  // OM Maximenu integration  
  if (!isset($vars['main_menu_tree']) && empty($vars['main_menu_tree'])) $vars['main_menu_tree'] = menu_tree('main-menu'); 

  // Generate menu tree from source of primary links
  $vars['main_menu_vars']        = ($vars['main_menu']) ? array('menu_name' => 'main-menu', 'menu' => $vars['main_menu'], 'menu_tree' => $vars['main_menu_tree']) : array();
  $vars['secondary_menu_tree']   = menu_tree('user-menu');
  $vars['secondary_menu_vars']   = ($vars['secondary_menu']) ? array('menu_name' => 'secondary-menu', 'menu' => $vars['secondary_menu'], 'menu_tree' => $vars['secondary_menu_tree']) : array();
  $vars['identity_vars']         = array('logo' => $vars['logo'], 'site_name' => $vars['site_name'], 'site_slogan' => $vars['site_slogan'], 'front_page' => $vars['front_page']);
  $vars['content_elements_vars'] = array('tabs' => $vars['tabs'], 'prefix' => $vars['title_prefix'], 'title' => $vars['title'], 'suffix' => $vars['title_suffix'], 'action' => $vars['action_links']);  
  //dsm($vars);
}

 
/**
 * Adding additional classes to blocks.
 */
function om_preprocess_block(&$vars) {

  $blocks = block_list($vars['block']->region);
	$vars['classes_array'][] = drupal_html_class('block-' . $vars['block_zebra']);
  $vars['classes_array'][] = drupal_html_class('block-' . $vars['block_id']);
  $vars['classes_array'][] = drupal_html_class('block-group-' . count($blocks));	
    
  if ($vars['block_id'] == 1) $vars['classes_array'][] = drupal_html_class('block-first');
	if ($vars['block_id'] == count($blocks)) $vars['classes_array'][] = drupal_html_class('block-last');

} 


/**
 * Act on blocks prior to rendering.
 *
 *
function om_block_list_alter(&$blocks) {
  //dsm($blocks);
}
*/
 
/**
 * Generates IE CSS links for LTR and RTL languages.
 */

function om_get_ie_styles($ie) {
  global $language;
  global $theme; 
  $iecss = '<link type="text/css" rel="stylesheet" media="all" href="' . base_path() . drupal_get_path('theme', $theme) . '/css/' . $ie . '.css" />';
  if ($language->direction == LANGUAGE_RTL) $iecss .= '<style type="text/css" media="all">@import "' . base_path() . drupal_get_path('theme', $theme) . '/css/ie-rtl.css";</style>';
  return $iecss;
}
